@@ -4,10 +4,10 @@ import torch
 import torch.nn as nn
 import torch.nn.functional as F
 
-class DuelingNet(nn.Module):
+class DuelingDQN(nn.Module):
 
     def __init__(self, input_size, hidden_size, output_size):
-        super(DuelingNet, self).__init__()
+        super(DuelingDQN, self).__init__()
 
         self.input_size = input_size
         self.hidden_size = hidden_size
