@@ -10,14 +10,14 @@ class MulNet(nn.Module):
         self.subnet_b = qnet_type(input_size_b, hidden_size, output_size)
 
         self.linear_i2h = nn.Linear(output_size*2, hidden_size)
-        self.linear_h2w = nn.Linear(hidden_size, 1)
+        self.linear_h2w = nn.Linear(hidden_size, output_size)
 
     def forward(self, x_a, x_b):
         y_a = self.subnet_a(x_a)
         y_b = self.subnet_b(x_b)
 
-        y = F.tanh(self.linear_i2h(torch.cat([y_a, y_b])))
-        y = self.linear_h2o(y)
+        y = F.tanh(self.linear_i2h(torch.cat([y_a, y_b], dim=-1)))
+        y = self.linear_h2w(y)
 
         return y
 
