@@ -16,8 +16,8 @@ class SplitAddNet(nn.Module):
         # w = F.tanh(self.linear_i2h(torch.cat([x_a, x_b], dim=-1)))
         # w = F.sigmoid(self.linear_h2w(w))
 
-        y_a = self.subnet_a(x_a) # * 0.5 # * w
-        y_b = self.subnet_b(x_b) # * 0.5 # * (1 - w)
+        y_a = self.subnet_a(x_a) * 0.5 # * w
+        y_b = self.subnet_b(x_b) * 0.5 # * (1 - w)
 
         return y_a, y_b
 
